@@ -1,15 +1,18 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Additional part for the PsychoPy library
-# Copyright (C) 2013 Wilbert van Ham, Radboud University Nijmegen
-# Distributed under the terms of the GNU General Public License (GPL) version 3 or newer.
-#from psychopy import core, visual, monitors, event
+"""RuSocSci module for the BITSI buttonbox
+
+Copyright (C) 2013 Wilbert van Ham, Radboud University Nijmegen
+Distributed under the terms of the GNU General Public License (GPL) version 3 or newer.
+"""
+from psychopy import core, visual, monitors, event
 import sys, serial, time, os, re, logging, glob
 import utils
 
 # our buttonbox has id 0403:6001 fro  its UART IC
 # make sure you have the pyusb module installed
 # for window you may need this: http://sourceforge.net/apps/trac/libusb-win32/wiki
+
 class Buttonbox():
 	def __init__(self, id=0, port=None):
 		[self._device, idString] = utils.open(id, port)
@@ -33,12 +36,12 @@ class Buttonbox():
 		keyboard if there is no buttonbox.
 
 		:Parameters:
-			keyList : **None** or []
-				Allows the user to specify a set of buttons to check for.
-				Only keypresses from this set of keys will be removed from the keyboard buffer.
-				If the keyList is None all keys will be checked and the key buffer will be cleared
-				completely. NB, pygame doesn't return timestamps (they are always 0)
-			There is no timestamp in our buttonbox. Use buttonbox.waitkeys if you want timestamps.
+		keyList : **None** or []
+		Allows the user to specify a set of buttons to check for.
+		Only keypresses from this set of keys will be removed from the keyboard buffer.
+		If the keyList is None all keys will be checked and the key buffer will be cleared
+		completely. NB, pygame doesn't return timestamps (they are always 0)
+		here is no timestamp in our buttonbox. Use buttonbox.waitkeys if you want timestamps.
 
 		:Author:
 			- 2013 written by Wilbert van Ham
@@ -65,14 +68,14 @@ class Buttonbox():
 		input from buttonbox. Implicitly clears buttonbox, so any preceding buttonpresses will be lost.
 
 		:Parameters:
-			maxWait : any numeric value.
-				Maximum number of seconds period and which buttons to wait for. 
-				Default is float('inf') which simply waits forever.
-			buttonList:
-				List of one character strings containing the buttons to react to.
-				All other button presses will be ignored. Notethat for BITSI 
-				buttonboxes the buttons are identified by capital letters upon press
-				and by lower case letters upon release.
+		maxWait : any numeric value.
+		Maximum number of seconds period and which buttons to wait for. 
+		Default is float('inf') which simply waits forever.
+		buttonList:
+		List of one character strings containing the buttons to react to.
+		All other button presses will be ignored. Notethat for BITSI 
+		buttonboxes the buttons are identified by capital letters upon press
+		and by lower case letters upon release.
 
 		Returns None if times out.
 		"""
@@ -86,7 +89,10 @@ class Buttonbox():
 		self._device.flushInput()
 		t = time.time()
 		while maxWait - (time.time() - t) > 0:
-			self._device.timeout = maxWait - (time.time() - t)
+			if maxWait == float("inf"):
+				self._device.timeout = None
+			else:
+				self._device.timeout = maxWait - (time.time() - t)
 			c = self._device.read(1)
 			if buttonList==None or c in buttonList:
 				# return
